Enum RehydrationError
pub enum RehydrationError {
MissingState(String),
State(SettingsError),
}Expand description
Errors that can occur during client rehydration.
Variants
MissingState(String)
A required value was not found in the state registry.
State(SettingsError)
An error occurred accessing or updating a setting in the state registry.