PasswordManagerClient

Struct PasswordManagerClient 

pub struct PasswordManagerClient(pub Client);
The main entry point for the Bitwarden Password Manager SDK

Tuple Fields

0: Client

Implementations

Source

impl PasswordManagerClient

pub fn new(settings: Option<ClientSettings>) -> Self

Initialize a new instance of the SDK client

pub fn builder() -> PasswordManagerClientBuilder

Returns a PasswordManagerClientBuilder for constructing a new PasswordManagerClient.

pub fn new_with_client_tokens( settings: Option<ClientSettings>, tokens: Arc<dyn ClientManagedTokens>, ) -> Self

Initialize a new instance of the SDK client with client-managed tokens

pub fn new_with_sync(settings: Option<ClientSettings>) -> Self

Initialize a new instance of the SDK client with SDK managed state and sync handlers registered

This will eventually replace new when the SDK fully owns sync on all clients.

pub fn platform(&self) -> PlatformClient

Platform operations

pub fn auth(&self) -> AuthClient

Auth operations

pub fn commercial(&self) -> CommercialPasswordManagerClient

Bitwarden licensed operations

pub fn crypto(&self) -> CryptoClient

Crypto operations

pub fn user_crypto_management(&self) -> UserCryptoManagementClient

Operations that manage the cryptographic machinery of a user account, including key-rotation

pub fn vault(&self) -> VaultClient

Vault item operations

pub fn exporters(&self) -> ExporterClient

Exporter operations

pub fn generator(&self) -> GeneratorClient

Generator operations

pub fn sends(&self) -> SendClient

Send operations

pub fn sync(&self) -> SyncClient

Sync operations