pub struct PasswordManagerClient(pub Client);Expand description
The main entry point for the Bitwarden Password Manager SDK
Tuple Fields
0: ClientImplementations
Sourceimpl PasswordManagerClient
impl PasswordManagerClient
Sourcepub fn new(settings: Option<ClientSettings>) -> Self
pub fn new(settings: Option<ClientSettings>) -> Self
Initialize a new instance of the SDK client
Sourcepub fn builder() -> PasswordManagerClientBuilder
pub fn builder() -> PasswordManagerClientBuilder
Returns a PasswordManagerClientBuilder for constructing a new PasswordManagerClient.
Sourcepub fn new_with_client_tokens(
settings: Option<ClientSettings>,
tokens: Arc<dyn ClientManagedTokens>,
) -> Self
pub fn new_with_client_tokens( settings: Option<ClientSettings>, tokens: Arc<dyn ClientManagedTokens>, ) -> Self
Initialize a new instance of the SDK client with client-managed tokens
Sourcepub fn new_with_sync(settings: Option<ClientSettings>) -> Self
pub fn new_with_sync(settings: Option<ClientSettings>) -> Self
Initialize a new instance of the SDK client with SDK managed state and sync handlers registered
This will eventually replace new when the SDK fully owns sync on all clients.
Sourcepub fn auth(&self) -> AuthClient
pub fn auth(&self) -> AuthClient
Auth operations
Sourcepub fn commercial(&self) -> CommercialPasswordManagerClient
pub fn commercial(&self) -> CommercialPasswordManagerClient
Bitwarden licensed operations
Sourcepub fn crypto(&self) -> CryptoClient
pub fn crypto(&self) -> CryptoClient
Crypto operations
Sourcepub fn user_crypto_management(&self) -> UserCryptoManagementClient
pub fn user_crypto_management(&self) -> UserCryptoManagementClient
Operations that manage the cryptographic machinery of a user account, including key-rotation
Sourcepub fn vault(&self) -> VaultClient
pub fn vault(&self) -> VaultClient
Vault item operations
Sourcepub fn exporters(&self) -> ExporterClient
pub fn exporters(&self) -> ExporterClient
Exporter operations
Sourcepub fn generator(&self) -> GeneratorClient
pub fn generator(&self) -> GeneratorClient
Generator operations
Sourcepub fn sends(&self) -> SendClient
pub fn sends(&self) -> SendClient
Send operations
Sourcepub fn sync(&self) -> SyncClient
pub fn sync(&self) -> SyncClient
Sync operations